History — Django Spine 0.3.2 documentation

### Navigation

- index
- previous |
- Django Spine 0.3.2 documentation »

# History

## 0.3.3 (2012-07-31)

- Fix issue #6

## 0.3.2 (2012-07-17)

- Fix setup module
  - issue #3
  - issue #5

## 0.0.2 (2012-06-17)

- Added the django-pipeline and eco package to requirements.txt
- modify examples
- modify README.rst

## 0.0.1 (2012-06-16)

- Alpha

### Navigation

- index
- previous |
- Django Spine 0.3.2 documentation »